@@ -33,8 +33,12 @@
 #include "gnome-i18nP.h"
 
 #include <gconf/gconf-client.h>
+#ifndef G_OS_WIN32
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
+#else
+#include <windows.h>
+#endif
 
 #include "gnome-exec.h"
 #include "gnome-util.h"
@@ -44,8 +48,6 @@
 
 #include "gnome-url.h"
 
-#include <popt.h>
-
 /**
  * gnome_url_show_with_env:
  * @url: The url or path to display.
@@ -63,6 +65,7 @@ gnome_url_show_with_env (const char  *url,
                          char       **envp,
 			 GError     **error)
 {
+#ifndef G_OS_WIN32
 	GnomeVFSResult result;
 
 	g_return_val_if_fail (url != NULL, FALSE);
@@ -117,7 +120,14 @@ gnome_url_show_with_env (const char  *url,
 			     GNOME_URL_ERROR_NOT_SUPPORTED,
 			     _("The default action does not support this protocol."));
 		break;
-			     
+
+	case GNOME_VFS_ERROR_CANCELLED:
+		g_set_error (error,
+		             GNOME_URL_ERROR,
+			     GNOME_URL_ERROR_CANCELLED,
+			     _("The request was cancelled."));
+		break;
+
 	default:
 		g_set_error (error,
 			     GNOME_URL_ERROR,
@@ -126,7 +136,21 @@ gnome_url_show_with_env (const char  *url,
 	}
 
 	return FALSE;
- }
+#else
+	/* FIXME: Just call ShellExecute... Good enough? */
+
+	if ((int) ShellExecute (HWND_DESKTOP, "open", url, NULL, NULL, SW_SHOWNORMAL) <= 32) {
+		g_set_error (error,
+			     GNOME_URL_ERROR,
+			     GNOME_URL_ERROR_LAUNCH,
+			     _("There was an error launching the default action command associated "
+			       "with this location."));
+		return FALSE;
+	}
+
+	return TRUE;
+#endif
+}
 
 /**
  * gnome_url_show:
